@@ -23,7 +23,7 @@
 #include "indexerextractortests.h"
 
 #include <QtTest>
-#include "qtest_kde.h"
+
 #include "simpleresult.h"
 #include "indexerextractortestsconfig.h"
 #include "extractors/plaintextextractor.h"
@@ -42,24 +42,10 @@ QString IndexerExtractorTests::testFilePath(const QString& fileName) const
 
 void IndexerExtractorTests::benchMarkPlainTextExtractor()
 {
-    PlainTextExtractor plugin(this, QVariantList());
+    QScopedPointer<ExtractorPlugin> plugin(new PlainTextExtractor(this, QVariantList()));
 
-    // generate a test file with varying number of words per line
-    QTemporaryFile file("XXXXXX.txt");
-    QVERIFY(file.open());
-    QByteArray chunk("foo bar ");
-    for (int line = 0; line < 10000; ++line) {
-        for (int i = 0; i < line % 100; ++i) {
-            file.write(chunk);
-        }
-        file.write("\n");
-    }
-
-    SimpleResult result(file.fileName(), "text/plain");
-
-    QBENCHMARK {
-        plugin.extract(&result);
-    }
+    SimpleResult result(testFilePath("plain_text_file.txt"), "text/plain");
+    plugin->extract(&result);
 }
 
 void IndexerExtractorTests::testPlainTextExtractor()
@@ -78,12 +64,13 @@ void IndexerExtractorTests::testPlainTextExtractor()
     QCOMPARE(result.types().size(), 1);
     QCOMPARE(result.types().first(), Type::Text);
 
-    QCOMPARE(result.properties().size(), 1);
+    QCOMPARE(result.properties().size(), 2);
+    QCOMPARE(result.properties().value(Property::WordCount), QVariant(17));
     QCOMPARE(result.properties().value(Property::LineCount), QVariant(4));
 
     content.replace(QLatin1Char('\n'), QLatin1Char(' '));
     QCOMPARE(result.text(), content);
 }
 
-QTEST_KDEMAIN_CORE(IndexerExtractorTests)
+QTEST_MAIN(IndexerExtractorTests)
 
