@@ -19,9 +19,11 @@
 
 
 #include "plaintextextractor.h"
-#include <QFile>
 
-#include <fstream>
+#include <QFile>
+#include <QTextStream>
+#include <QDebug>
+#include <KService>
 
 using namespace KFileMetaData;
 
@@ -38,23 +40,33 @@ QStringList PlainTextExtractor::mimetypes() const
 
 void PlainTextExtractor::extract(ExtractionResult* result)
 {
-    std::string line;
-    int lines = 0;
+    QFile file(result->inputUrl());
 
-    std::ifstream fstream(QFile::encodeName(result->inputUrl()));
-    if (!fstream.is_open()) {
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         return;
     }
 
-    while (std::getline(fstream, line)) {
-        QByteArray arr = QByteArray::fromRawData(line.c_str(), line.size());
-        result->append(QString::fromUtf8(arr));
+    int lines = 0;
+    int words = 0;
+
+    QRegExp wordsRegex("\\b\\w+\\b");
+
+    QTextStream ts(&file);
+    while (!ts.atEnd()) {
+        QString str = ts.readLine();
+        result->append(str);
 
         lines += 1;
+        words += str.count(wordsRegex);
     }
 
+    result->add(Property::WordCount, words);
     result->add(Property::LineCount, lines);
     result->addType(Type::Text);
+
+    return;
 }
 
-KFILEMETADATA_EXPORT_EXTRACTOR(KFileMetaData::PlainTextExtractor, "kfilemetadata_plaintextextractor")
+K_PLUGIN_FACTORY(factory, registerPlugin<PlainTextExtractor>();)
+
+#include "plaintextextractor.moc"
